@@ -5,8 +5,11 @@ class SchedulerLogTask(str, Enum):
     COMPILEPROJECT = "compileProject"
     DOWNLOADCSV = "downloadCsv"
     HANDLESCHEDULEDDELIVERY = "handleScheduledDelivery"
+    SEMANTICLAYER = "semanticLayer"
     SENDEMAILNOTIFICATION = "sendEmailNotification"
     SENDSLACKNOTIFICATION = "sendSlackNotification"
+    SQLRUNNER = "sqlRunner"
+    SQLRUNNERPIVOTQUERY = "sqlRunnerPivotQuery"
     TESTANDCOMPILEPROJECT = "testAndCompileProject"
     UPLOADGSHEETFROMQUERY = "uploadGsheetFromQuery"
     UPLOADGSHEETS = "uploadGsheets"
